@@ -4,12 +4,9 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef VERSION_H
-#define VERSION_H
+#pragma once
 
 // Shallow version history:
 //   6.2.0 - pre repository split
 //   7.0.0 - post repository split
 #define KACTIVITIES_VERSION_STRING QStringLiteral("7.0.0")
-
-#endif // VERSION_H
