@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PLUGINS_SQLITE_RESOURCE_LINKING_H
-#define PLUGINS_SQLITE_RESOURCE_LINKING_H
+#pragma once
 
 // Qt
 #include <QObject>
@@ -60,7 +59,7 @@ private Q_SLOTS:
     void onCurrentActivityChanged(const QString &activity);
 
 private:
-    bool validateArguments(QString &initiatingAgent, QString &targettedResource, QString &usedActivity);
+    bool validateArguments(QString &initiatingAgent, QString &targettedResource, QString &usedActivity, bool checkFilesExist = true);
 
     QString currentActivity() const;
 
@@ -69,5 +68,3 @@ private:
     std::unique_ptr<QSqlQuery> unlinkResourceFromActivityQuery;
     std::unique_ptr<QSqlQuery> isResourceLinkedToActivityQuery;
 };
-
-#endif // PLUGINS_SQLITE_RESOURCE_LINKING_H
